﻿Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports _4_PhoneBook.ViewModel

Class MainWindow
    Implements INotifyPropertyChanged
    Dim dp As New ContactsDataProvider()

    Private Sub MainWindow_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded
        AllContacts = New ObservableCollection(Of ContactViewModel)

        LoadData()
        Me.DataContext = Me
    End Sub

    Private Sub LoadData()
        _allContactsModels = dp.GetAllContacts(True).ToList()
        _allContactsModels.ForEach((Sub(x) AllContacts.Add(New ContactViewModel(x))))

        AllContactsView = CollectionViewSource.GetDefaultView(AllContacts)
        AllContactsView.Filter = AddressOf Contacts_Filter
        AllContactsView.GroupDescriptions.Add(New PropertyGroupDescription("FirstLastNameLetter"))

        SelectedContact = AllContacts.FirstOrDefault()
    End Sub

    Private Function Contacts_Filter(obj As Object) As Boolean
        Dim c As ContactViewModel = CType(obj, ContactViewModel)
        Return c.FullName.ToLower().Contains(FilterString.ToLower()) Or c.Note.ToLower().Contains(FilterString.ToLower())
    End Function

    Private _allContacts As ObservableCollection(Of ContactViewModel)
    Private _allContactsModels As List(Of Model.Contact)
    Public Property AllContacts() As ObservableCollection(Of ContactViewModel)
        Get
            Return _allContacts
        End Get
        Set(ByVal value As ObservableCollection(Of ContactViewModel))
            _allContacts = value
            RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(NameOf(AllContacts)))
        End Set
    End Property

    Private _allContactsView As ICollectionView
    Public Property AllContactsView() As ICollectionView
        Get
            Return _allContactsView
        End Get
        Set(ByVal value As ICollectionView)
            _allContactsView = value
            RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(NameOf(AllContactsView)))
        End Set
    End Property



    Private _selectedContact As ContactViewModel
    Public Property SelectedContact() As ContactViewModel
        Get
            Return _selectedContact
        End Get
        Set(ByVal value As ContactViewModel)
            _selectedContact = value
            RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(NameOf(SelectedContact)))
        End Set
    End Property


    Private _filterString As String = ""
    Public Property FilterString() As String
        Get
            Return _filterString
        End Get
        Set(ByVal value As String)
            _filterString = value
            AllContactsView.Refresh()
            RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(NameOf(FilterString)))
        End Set
    End Property



    Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged

    Private Sub ContactItem_Click(sender As Object)
        SelectedContact = CType(CType(sender, Border).DataContext, ContactViewModel)
    End Sub

    Private Sub btnEditContact(sender As Object, e As RoutedEventArgs)
        Dim dlgWin As New Window()
        dlgWin.SizeToContent = SizeToContent.WidthAndHeight
        dlgWin.Content = New uclEditContact()
        dlgWin.DataContext = SelectedContact
        If dlgWin.ShowDialog() Then
            dp.SaveContacts(_allContactsModels)
        Else
            AllContacts.Clear()
            LoadData()
        End If
    End Sub
End Class

